@@ -13,6 +13,12 @@
 #' If character spaces are padded.  The \code{detect} attempts to determine if x 
 #' is numeric (d) or not (s).
 #' @return Returns a character vector every element padded with 0/spaces.
+#' @note \code{pad} is a wrapper for the \code{\link[base]{sprintf}} function.
+#' \code{pad} may behave differently on various platforms in accordance with the
+#' documentation for \code{\link[base]{sprintf}}: "actual implementation will 
+#' follow the C99 standard and fine details (especially the behaviour under user 
+#' error) may depend on the platform."  See \code{\link[base]{sprintf}} for more 
+#' information.
 #' @export
 #' @seealso \code{\link[base]{sprintf}}
 #' @examples
@@ -32,9 +38,29 @@ pad <- function (x, padding = max(nchar(as.character(x))), sort = TRUE,
     if (is.na(type)) {
         type <- ifelse(is.numeric(x), "d", "s")
     }
-    x <- sprintf(paste0("%0", padding, type), x)
+    x <- sprintf_ish(x, padding, type)
     if (sort) {
         x <- sort(x)
     }
     x
 }
+
+sprintf_ish <- function(x, padding, type){
+    OS <- Sys.info()[['sysname']]
+ 
+    if (OS %in% c("Windows", "Linux")) {
+        sprintf(paste0("%0", padding, type), x)
+    } else {
+        type <- ifelse(type == "s", " ", "0")
+        pads <- sapply(padding - nchar(x), function(i)  {
+            if (i == 0) return("")
+            paste(rep(type, i), collapse = "")
+        })
+        paste0(pads, x)
+      
+    }
+}
+
+
+
+
